require "./test/collect_tests.rb"
require "./run.rb"
require "stringio"

tests = collect_tests

tests.filter!{|source,expected,from,input,no_pp|
  !expected[/\s*ERROR|RANK ERROR|stack level too deep/] && !source[/version/] && (input=="" || input=="777" || input==nil)
}

$out = ""
def output s
  $out << s
end

puts Header
puts 'strip = f . f where f = reverse . dropWhile isSpace'
puts 'iogInput = 777'
puts 'iogMain rawArgs inputIgnored = concat (map (\(a,b,c)-> "found: " ++ strip a ++ " expected: " ++ strip b ++ " from: " ++ c ++ "\n") $ filter (\(a,b,c) -> strip a /= strip b) tests) ++ "\n" ++ show (length tests) ++ " hs tests\n" where
 tests = ['+
tests.map{|source,expected,from,input,no_pp|
  size = if expected[/\.\.\./]
    expected = $`
    $`.size
  else
    1000
  end
  begin
    ir3, ir3_ind = gen_graph(source.strip,StringIO.new(input||""), pp_sep: no_pp ? nil : " ")
    $out = "  (take #{size} (let\n -- %s\n" % (source.lines.map(&:chomp)*";")
    to_hs_main(ir3,ir3_ind)
    $out + ("  ),%p,%p)" % [expected,from]).gsub("\\#","#") # these escapes not valid in haskell
  rescue IogiiError => e
    STDERR.puts "failed to compile hs for: " + source
    raise e
  end
}*"\n  ,"+"\n  ]\n"

